@@ -1,4 +1,4 @@
-﻿(function ($, document) {
+﻿define([], function () {
 
     function reloadItems(page) {
 
@@ -26,12 +26,12 @@
     pageIdOn('pageinit', "channelsPage", function () {
 
         var page = this;
-        var pages = page.querySelector('neon-animated-pages');
+        var pageTabsContainer = page.querySelector('.pageTabsContainer');
 
-        pages.addEventListener('tabchange', function (e) {
-            loadTab(page, parseInt(e.target.selected));
+        pageTabsContainer.addEventListener('tabchange', function (e) {
+            loadTab(page, parseInt(e.detail.selectedTabIndex));
         });
 
     });
 
-})(jQuery, document);
\ No newline at end of file
+});
\ No newline at end of file
